pub struct DataDirectory {
pub virtual_address: u32,
pub size: u32,
}Expand description
One (RVA, size) pair from the optional header’s data directory array. Both fields are zero when the entry is unused.
Fields
virtual_address: u32size: u32Trait Implementations
Sourceimpl Clone for DataDirectory
impl Clone for DataDirectory
Sourcefn clone(&self) -> DataDirectory
fn clone(&self) -> DataDirectory
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataDirectory
impl Debug for DataDirectory
Sourceimpl PartialEq for DataDirectory
impl PartialEq for DataDirectory
Sourcefn eq(&self, other: &DataDirectory) -> bool
fn eq(&self, other: &DataDirectory) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for DataDirectory
impl Eq for DataDirectory
impl StructuralPartialEq for DataDirectory